"""
All views accept extra parameter: auth_decorator

Example:
from django.contrib.auth.decorators import login_required
urlpatterns += patterns('',
   (r'^celery/', include('ua2.celery.urls'), {'auth_decorator': login_required}),
)

With this decorator each request passing through authorization

"""
from django.conf.urls.defaults import patterns, url


urlpatterns = patterns('ua2.celery.views',
    url('^status/(?P<task_id>.*)/$', 'task_status', name='ua2-celery-task-status'),
)



from ua2.ajax import accept_ajax
from celery.result import AsyncResult

from ua2.celery.auth import auth_decorator


@accept_ajax
@auth_decorator
def task_status(request, task_id):
    """
    Different from djcelery.views.task_status:
       - not provide information about traceback
       - provide authorization decorator
    """
    result = AsyncResult(task_id)

    return {'task_id': task_id,
            'status': result.status,
            'result': result.result}




def auth_decorator(view_func):
    def _wrap(request, *args, **kwargs):
        auth_handler = kwargs.get('auth_decorator')
        if auth_handler:
            del kwargs['auth_decorator']
            return auth_handler(view_func)(request, *args, **kwargs)
        return view_func(request, *args, **kwargs)

    return _wrap



#!/usr/bin/env python
try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages


Name = 'ua2.celery'
ProjecUrl = "https://bitbucket.org/ua2web/ua2.celery"
Version = '0.0.1'
Author = 'Vic'
AuthorEmail = 'vic@ua2web.com'
Maintainer = 'Vic'
Summary = 'Extended handlers and helpers worh with celery'
License = 'BSD License'
ShortDescription = Summary
Description = Summary

needed = [
]

EagerResources = [
    'ua2',
]

ProjectScripts = [
]

PackageData = {
    '': ['*.*'],
}

# Make exe versions of the scripts:
EntryPoints = {
}

setup(
    url=ProjecUrl,
    name=Name,
    zip_safe=False,
    version=Version,
    author=Author,
    author_email=AuthorEmail,
    description=ShortDescription,
    long_description=Description,
    license=License,
    scripts=ProjectScripts,
    install_requires=needed,
    include_package_data=True,
    packages=find_packages('src'),
    package_data=PackageData,
    package_dir={'': 'src'},
    eager_resources=EagerResources,
    entry_points=EntryPoints,
    namespace_packages=['ua2'],
)
